@@ -11,7 +11,7 @@ from ocp_resources.constants import NOT_FOUND_ERROR_EXCEPTION_DICT
 from ocp_resources.resource import ResourceEditor
 from ocp_resources.rhmi import RHMI
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
-from ocp_utilities.infra import get_client
+from ocp_utilities.infra import create_icsp, create_update_secret, get_client
 from simple_logger.logger import get_logger
 
 from ocm_python_wrapper.exceptions import MissingResourceError
@@ -250,6 +250,7 @@ class ClusterAddOn(Cluster):
     def __init__(self, client, cluster_name, addon_name):
         super().__init__(client=client, name=cluster_name)
         self.addon_name = addon_name
+        self.addon_version = self.addon_info()["version"]["id"]
 
     def addon_info(self):
         return self.client.api_clusters_mgmt_v1_addons_addon_id_get(
@@ -277,7 +278,13 @@ class ClusterAddOn(Cluster):
                 f"{self.addon_name} missing some required parameters {missing_parameter}"
             )
 
-    def install_addon(self, parameters=None, wait=True, wait_timeout=TIMEOUT_30MIN):
+    def install_addon(
+        self,
+        parameters=None,
+        wait=True,
+        wait_timeout=TIMEOUT_30MIN,
+        brew_pull_secret=None,
+    ):
         """
         Install addon on the cluster
 
@@ -285,6 +292,18 @@ class ClusterAddOn(Cluster):
             parameters (list): List of dict.
             wait (bool): True to wait for addon to be installed.
             wait_timeout (int): Timeout in seconds to wait for addon to be installed.
+            brew_pull_secret (dict): secret data dict for pulling images from brew registry,
+                example: {
+                    "auths":{
+                    <registry_name>:
+                        {"auth": <auth_token>,
+                        "email": <auth_email>},
+                    ...,
+                    <registry_name>:
+                        {"auth": <auth_token>,
+                        "email": <auth_email>}
+                    }
+                }
         """
         addon = AddOn(id=self.addon_name)
         _addon_installation_dict = {
@@ -300,8 +319,13 @@ class ClusterAddOn(Cluster):
                 )
 
             _addon_installation_dict["parameters"] = {"items": _parameters}
+        if (
+            self.addon_name == "managed-odh"
+            and "stage" in self.client.api_client.configuration.host
+        ):
+            self.create_rhods_brew_config(secret_data_dict=brew_pull_secret)
 
-        LOGGER.info(f"Installing addon {self.addon_name}")
+        LOGGER.info(f"Installing addon {self.addon_name} v{self.addon_version}")
         res = self.client.api_clusters_mgmt_v1_clusters_cluster_id_addons_post(
             cluster_id=self.cluster_id,
             add_on_installation=AddOnInstallation(
@@ -320,7 +344,7 @@ class ClusterAddOn(Cluster):
                 state=self.State.READY, wait_timeout=wait_timeout
             )
 
-        LOGGER.info(f"{self.addon_name} successfully installed")
+        LOGGER.info(f"{self.addon_name} v{self.addon_version} successfully installed")
         return res
 
     def addon_installation_instance(self):
@@ -355,7 +379,7 @@ class ClusterAddOn(Cluster):
             raise
 
     def uninstall_addon(self, wait=True, wait_timeout=TIMEOUT_30MIN):
-        LOGGER.info(f"Removing addon {self.addon_name}")
+        LOGGER.info(f"Removing addon {self.addon_name} v{self.addon_version}")
         res = self.client.api_clusters_mgmt_v1_clusters_cluster_id_addons_addoninstallation_id_delete(
             cluster_id=self.cluster_id,
             addoninstallation_id=self.addon_name,
@@ -366,7 +390,7 @@ class ClusterAddOn(Cluster):
             ) in self.addon_installation_instance_sampler(wait_timeout=wait_timeout):
                 if not _addon_installation_instance:
                     return True
-        LOGGER.info(f"{self.addon_name} was successfully removed")
+        LOGGER.info(f"{self.addon_name} v{self.addon_version} was successfully removed")
         return res
 
     @staticmethod
@@ -388,3 +412,20 @@ class ClusterAddOn(Cluster):
         ResourceEditor(
             patches={rhmi: {"spec": {"useClusterStorage": "false"}}}
         ).update()
+
+    @staticmethod
+    def create_rhods_brew_config(secret_data_dict):
+        create_icsp(
+            icsp_name="brew-registry",
+            repository_digest_mirrors=[
+                {
+                    "source": "registry.redhat.io/rhods",
+                    "mirrors": ["brew.registry.redhat.io/rhods"],
+                }
+            ],
+        )
+        create_update_secret(
+            secret_data_dict=secret_data_dict,
+            name="pull-secret",  # pragma: allowlist secret
+            namespace="openshift-config",
+        )
